@@ -3,13 +3,10 @@
 #include <torch/csrc/jit/tensorexpr/expr.h>
 #include <torch/csrc/jit/tensorexpr/ir.h>
 
-#include <deque>
+#include <utility>
 #include <vector>
 
-namespace torch {
-namespace jit {
-namespace tensorexpr {
-namespace analysis {
+namespace torch::jit::tensorexpr::analysis {
 
 // A simple class containing the start and end of a range in a single dimension.
 struct TORCH_API Bound {
@@ -22,7 +19,7 @@ struct TORCH_API Bound {
   bool swapped{false};
 
   Bound() = default;
-  Bound(ExprPtr s, ExprPtr e) : start(s), end(e) {}
+  Bound(ExprPtr s, ExprPtr e) : start(std::move(s)), end(std::move(e)) {}
 
   void print() const;
   bool equals(const Bound& other) const;
@@ -38,7 +35,7 @@ struct TORCH_API Bound {
   bool operator>(const Bound& other) const;
   bool operator>=(const Bound& other) const;
 
-  void swap() {
+  void swap() noexcept {
     std::swap(start, end);
     swapped = !swapped;
   }
@@ -57,22 +54,27 @@ struct BoundHash {
 //     Contains: All elements in the Bound B are in the Bound B.
 //     PartialOverlap: Any elements in the Bound B are in the Bound A.
 //     NoOverlap: No elements in the Bound A are in the bound B.
-enum OverlapKind { ContainedOrEqual, Contains, PartialOverlap, NoOverlap };
+enum class OverlapKind {
+  ContainedOrEqual,
+  Contains,
+  PartialOverlap,
+  NoOverlap
+};
 
 // The Bound comparison result.
-//     TRUE: Every Bound element always satifies the given comparison operator
-//     FALSE: Every Bound element always does NOT satify the given comparison
+//     True: Every Bound element always satisfies the given comparison operator
+//     False: Every Bound element always does NOT satisfy the given comparison
 //     operator
-//     NOT_DETERMINED: Some elements satify the given comparison operator and
+//     NotDetermined: Some elements satisfy the given comparison operator and
 //     some elements not
-enum CmpEvalResult { TRUE, FALSE, NOT_DETERMINED };
+enum class CmpEvalResult { True, False, NotDetermined };
 
 // Returns the kind of overlap between Bound A and Bound A in a single
 // dimension.
-OverlapKind TORCH_API boundOverlap(Bound A, Bound B);
+OverlapKind TORCH_API boundOverlap(const Bound& A, const Bound& B);
 
 // The comparison is conservative and the compare result is deterministic.
-// It means that every element of the Bound to be compared needs to satisfiy
+// It means that every element of the Bound to be compared needs to satisfy
 // the given comparison operator.
 CmpEvalResult TORCH_API compareBound(
     const Bound& a,
@@ -106,7 +108,7 @@ OverlapKind TORCH_API overlaps(const IndexBounds& a, const IndexBounds& b);
 //
 // Note: this doesn't use IndexBounds because the Bounds returned do not
 // represent multiple different dimensions.
-std::vector<Bound> TORCH_API subtractBound(Bound a, Bound b);
+std::vector<Bound> TORCH_API subtractBound(const Bound& a, const Bound& b);
 
 // Returns the bound slices created by subtracting the IndexBounds B from A.
 std::vector<IndexBounds> TORCH_API subtractIndicesBounds(
@@ -116,7 +118,4 @@ std::vector<IndexBounds> TORCH_API subtractIndicesBounds(
 std::vector<IndexBounds> TORCH_API
 subtractIndicesBounds(const IndexBounds& A, const IndexBounds& B);
 
-} // namespace analysis
-} // namespace tensorexpr
-} // namespace jit
-} // namespace torch
+} // namespace torch::jit::tensorexpr::analysis
